@@ -175,8 +175,9 @@
 #' pushViewport(viewport(layout.pos.row = 1, layout.pos.col = 1))
 #'
 #' # Visualize the clustering (using Spectral between clusters and MDS within)
-#' res <- dissplot(d, l, method = list(inter = "Spectral", intra = "MDS"),
-#'   main = "K-Means + Seriation", newpage = FALSE)
+#' res <- dissplot(d, l, method = list(inter_cluster = "Spectral", 
+#'                                     intra_cluster = "MDS"),
+#'     main = "K-Means + Seriation", newpage = FALSE)
 #'
 #' popViewport()
 #' pushViewport(viewport(layout.pos.row = 1, layout.pos.col = 2))
@@ -200,7 +201,7 @@
 #' plot(res, main = "K-Means + Seriation (logistic scale)",
 #'   col = gray(
 #'     plogis(seq(max(res$x_reordered), min(res$x_reordered), length.out = 100),
-#'       location = 2, scale = 1/2, log = FALSE)
+#'       location = 2, scale = 1/2, log.p = FALSE)
 #'     ),
 #'   newpage = FALSE)
 #'
@@ -238,7 +239,8 @@
 #'   labs(title = "K-means + Seriation", fill = "Distances\n(Euclidean)")
 #'
 #' # Diverging color palette with manual set midpoint and different seriation methods
-#' ggdissplot(d, l, method = list(inter = "Spectral", intra = "MDS")) +
+#' ggdissplot(d, l, method = list(inter_cluster = "Spectral", 
+#'                                intra_cluster = "MDS")) +
 #'   labs(title = "K-Means + Seriation", subtitle = "biased color scale") +
 #'   scale_fill_gradient2(midpoint = median(d))
 #'
@@ -249,28 +251,30 @@
 #' cubic_dist_trans <- trans_new(
 #'   name = "cubic",
 #'   # note that we have to do the inverse transformation for distances
-#'   trans = function(x) x^(1/3),
+#'   transform = function(x) x^(1/3),
 #'   inverse = function(x) x^3
 #' )
 #'
-#' ggdissplot(d, l, method = list(inter = "Spectral", intra = "MDS")) +
+#' ggdissplot(d, l, method = list(inter_cluster = "Spectral", 
+#'                                intra_cluster = "MDS")) +
 #'   labs(title = "K-Means + Seriation", subtitle = "cubic + biased color scale") +
 #'   scale_fill_gradient(low = "black", high = "white",
-#'     limit = c(0,2), na.value = "white",
-#'     trans = cubic_dist_trans)
+#'     limits = c(0,2), na.value = "white",
+#'     transform = cubic_dist_trans)
 #'
 #' # Use gray scale with logistic transformation
 #' logis_2_.5_dist_trans <- trans_new(
 #'   name = "Logistic transform (location, scale)",
 #'   # note that we have to do the inverse transformation for distances
-#'   trans = function(x) plogis(x, location = 2, scale = .5, log = FALSE),
-#'   inverse = function(x) qlogis(x, location = 2, scale = .5, log = FALSE),
+#'   transform = function(x) plogis(x, location = 2, scale = .5, log.p = FALSE),
+#'   inverse = function(x) qlogis(x, location = 2, scale = .5, log.p = FALSE),
 #' )
 #'
-#' ggdissplot(d, l, method = list(inter = "Spectral", intra = "MDS")) +
+#' ggdissplot(d, l, method = list(inter_cluster = "Spectral", 
+#'                                intra_cluster = "MDS")) +
 #'   labs(title = "K-Means + Seriation", subtitle = "logistic color scale") +
 #'   scale_fill_gradient(low = "black", high = "white",
-#'     trans = logis_2_.5_dist_trans,
+#'     transform = logis_2_.5_dist_trans,
 #'     breaks = c(0, 1, 2, 3, 4))
 #' }
 #' @export
@@ -378,7 +382,7 @@ dissplot <- function(x,
       ## reorder whole matrix if no labels are given
       order <- seriate(x,
         method = method$inter_cluster,
-        control = control$inter)[[1]]
+        control = control$inter_cluster)[[1]]
 
       method$inter_cluster <- if (!is.null(attr(order, "method")))
         attr(order, "method")
@@ -401,7 +405,7 @@ dissplot <- function(x,
         cluster_order <- seriate(
           as.dist(cluster_dissimilarities),
           method = method$inter_cluster,
-          control = control$inter
+          control = control$inter_cluster
         )[[1]]
 
         method$inter_cluster <-
@@ -455,7 +459,7 @@ dissplot <- function(x,
               intra_order <-
                 seriate(block,
                   method = method$intra_cluster,
-                  control = control$intra)[[1]]
+                  control = control$intra_cluster)[[1]]
 
               method$intra_cluster <-
                 if (!is.null(attr(intra_order, "method")))
@@ -942,8 +946,8 @@ print.reordered_cluster_dissimilarity_matrix <-
 
     cat("\n")
     cat("used seriation methods\n")
-    cat(gettextf("inter-cluster: '%s'\n", x$seriation_methods$inter))
-    cat(gettextf("intra-cluster: '%s'\n", x$seriation_methods$intra))
+    cat(gettextf("inter-cluster: '%s'\n", x$seriation_methods$inter_cluster))
+    cat(gettextf("intra-cluster: '%s'\n", x$seriation_methods$intra_cluster))
 
     cat("\n")
     cat(gettextf(
@@ -962,7 +966,6 @@ print.reordered_cluster_dissimilarity_matrix <-
     method = c("avg", "min", "max",
       "Hausdorff")) {
     method <- match.arg(method)
-    ## FIXME: Implement Hausdorff
 
     linkage <- if (method == "avg")
       mean
